Learn R Programming

walkr (version 0.3.3)

dikin_walk: Dikin Walk

Description

This function implements the Dikin Walk using the Hessian of the Log barrier function. Note that a $r$ of 1 guarantees that the ellipsoid generated won't leave our polytope $K$ (see Theorems online)

Usage

dikin_walk(A, b, x0 = list(), points, r = 1, thin = 1, burn = 0, chains = 1)

Arguments

A
is the lhs of Ax
b
is the rhs of Ax
x0
is the starting point (a list of points)
points
is the number of points we want to sample
r
is the radius of the ellipsoid (1 by default)
thin
every thin-th point is stored
burn
the first burn points are deleted
chains
is the number of chains we run

Value

a list of chains of the sampled points, each chain being a matrix object with each column as a point

Examples

Run this code
## Not run: 
# ## note that this Ax <= b is different from Ax=b that the
# ## user specifies for walkr (see transformation section in vignette)
# dikin_walk(A = A, b = b, x0, points = 100,
#            r = 1thin = 1, burn = 0, chains = 1)
# ## End(Not run)

Run the code above in your browser using DataLab